@@ -13,9 +13,9 @@ use std::{
 };
 
 use der::{
-    asn1::{ContextSpecificRef, OctetStringRef, Utf8StringRef},
     DecodeValue, Document, Encode, EncodeValue, ErrorKind, FixedTag, Length, Reader, Sequence,
     SliceReader, Tag, TagMode, TagNumber, Tagged, Writer,
+    asn1::{ContextSpecificRef, OctetStringRef, Utf8StringRef},
 };
 use log::{error, warn};
 
@@ -117,7 +117,7 @@ pub struct Trie {
 }
 
 fn io_error(e: impl Into<Box<dyn Error + Send + Sync>>) -> io::Error {
-    io::Error::new(io::ErrorKind::Other, e)
+    io::Error::other(e)
 }
 
 impl Trie {
@@ -174,19 +174,11 @@ impl Trie {
 
 /// Options and flags which can be used to configure how a trie dictionary is
 /// opened.
-#[derive(Debug, Clone, Copy, PartialEq, Eq)]
+#[derive(Debug, Clone, Copy, PartialEq, Eq, Default)]
 pub struct TrieOpenOptions {
     fuzzy_search: bool,
 }
 
-impl Default for TrieOpenOptions {
-    fn default() -> Self {
-        Self {
-            fuzzy_search: false,
-        }
-    }
-}
-
 impl TrieOpenOptions {
     pub fn new() -> TrieOpenOptions {
         TrieOpenOptions::default()
@@ -1176,7 +1168,7 @@ impl DictionaryBuilder for TrieBuilder {
             .duration_since(SystemTime::UNIX_EPOCH)
             .map(|du| du.subsec_micros())
             .unwrap_or_default();
-        tmpname.set_file_name(format!("chewing-{}.dat", pseudo_random));
+        tmpname.set_file_name(format!("chewing-{pseudo_random}.dat"));
         let database = File::create(&tmpname)?;
         let mut writer = BufWriter::new(&database);
         self.write(&mut writer)?;
@@ -1206,8 +1198,8 @@ mod tests {
 
     use crate::{
         dictionary::{
-            trie::TrieBuilderNode, Dictionary, DictionaryBuilder, DictionaryInfo, LookupStrategy,
-            Phrase, TrieOpenOptions,
+            Dictionary, DictionaryBuilder, DictionaryInfo, LookupStrategy, Phrase, TrieOpenOptions,
+            trie::TrieBuilderNode,
         },
         syl,
         zhuyin::Bopomofo,
