@@ -20,8 +20,8 @@ use log::{debug, info, trace, warn};
 
 use crate::{
     conversion::{
-        full_width_symbol_input, special_symbol_input, ChewingEngine, ConversionEngine, Interval,
-        Symbol,
+        ChewingEngine, ConversionEngine, Interval, Symbol, full_width_symbol_input,
+        special_symbol_input,
     },
     dictionary::{
         Dictionary, DictionaryMut, Layered, LookupStrategy, SystemDictionaryLoader,
@@ -191,13 +191,16 @@ pub(crate) struct SharedState {
 
 impl Editor {
     pub fn chewing() -> Result<Editor, Box<dyn Error>> {
-        let system_dict = SystemDictionaryLoader::new().load()?;
+        let sys_loader = SystemDictionaryLoader::new();
+        let base_dict = sys_loader.load()?;
+        let drop_in_dict = sys_loader.load_drop_in()?;
+        let system_dict = Vec::from_iter(base_dict.into_iter().chain(drop_in_dict));
         let user_dict = UserDictionaryLoader::new().load()?;
         let estimate = LaxUserFreqEstimate::max_from(user_dict.as_ref());
         let dict = Layered::new(system_dict, user_dict);
         let conversion_engine = Box::new(ChewingEngine::new());
-        let abbrev = SystemDictionaryLoader::new().load_abbrev()?;
-        let sym_sel = SystemDictionaryLoader::new().load_symbol_selector()?;
+        let abbrev = sys_loader.load_abbrev()?;
+        let sym_sel = sys_loader.load_symbol_selector()?;
         let editor = Editor::new(conversion_engine, dict, estimate, abbrev, sym_sel);
         Ok(editor)
     }
@@ -244,6 +247,9 @@ impl Editor {
     pub fn ack(&mut self) {
         self.shared.commit_buffer.clear();
     }
+    pub fn clear_composition_editor(&mut self) {
+        self.shared.com.clear();
+    }
     pub fn clear_syllable_editor(&mut self) {
         self.shared.syl.clear();
     }
@@ -393,7 +399,7 @@ impl Editor {
         &self.shared.commit_buffer
     }
     pub fn commit(&mut self) -> Result<(), EditorError> {
-        if !self.is_entering() || self.shared.com.is_empty() {
+        if self.shared.com.is_empty() {
             return Err(EditorError::InvalidState);
         }
         self.shared.commit();
@@ -517,7 +523,7 @@ impl SharedState {
             self.conv
                 .convert(&self.dict, self.com.as_ref())
                 .next()
-                .unwrap()
+                .unwrap_or_default()
         }
     }
     fn intervals(&self) -> impl Iterator<Item = Interval> {
@@ -540,7 +546,7 @@ impl SharedState {
         let result = self.learn_phrase_in_range_quiet(start, end);
         match &result {
             Ok(phrase) => {
-                self.notice_buffer = format!("加入：{}", phrase);
+                self.notice_buffer = format!("加入：{phrase}");
                 Ok(())
             }
             Err(msg) => {
@@ -578,14 +584,12 @@ impl SharedState {
             return Err(format!("已有：{phrase}"));
         }
         let result = self
-            .dict
-            .add_phrase(&syllables, (phrase.as_ref(), 100).into())
-            .map(|_| phrase)
+            .learn_phrase(&syllables, &phrase)
             .map_err(|_| "加詞失敗：字數不符或夾雜符號".to_owned());
         if result.is_ok() {
             self.dirty_level += 1;
         }
-        result
+        result.map(|_| phrase)
     }
     fn learn_phrase(
         &mut self,
@@ -763,6 +767,13 @@ impl BasicEditor for Editor {
             Transition::Spin(behavior) => self.shared.last_key_behavior = behavior,
         }
 
+        if self.shared.options.conversion_engine == ConversionEngineKind::SimpleEngine
+            && self.is_entering()
+            && !self.shared.com.is_empty()
+        {
+            self.shared.commit();
+        }
+
         if self.is_entering() && self.shared.last_key_behavior == EditorKeyBehavior::Absorb {
             self.shared.try_auto_commit();
         }
@@ -843,7 +854,11 @@ impl Entering {
         }
     }
     fn start_symbol_input(&self, editor: &mut SharedState) -> Transition {
-        Transition::ToState(Box::new(Selecting::new_symbol(editor)))
+        if editor.sym_sel.is_empty() {
+            self.spin_bell()
+        } else {
+            Transition::ToState(Box::new(Selecting::new_symbol(editor)))
+        }
     }
     fn start_enter_syllable(&self) -> Transition {
         Transition::ToState(Box::new(EnteringSyllable))
@@ -1031,25 +1046,16 @@ impl State for Entering {
                             }
                         }
                     }
-                    LanguageMode::Chinese if shared.options.easy_symbol_input => {
-                        // Priortize symbol input
-                        if let Some(expended) = shared.abbr.find_abbrev(ev.unicode) {
-                            expended
-                                .chars()
-                                .for_each(|ch| shared.com.insert(Symbol::from(ch)));
-                            return self.spin_absorb();
-                        }
-                        if let Some(symbol) = special_symbol_input(ev.unicode) {
-                            shared.com.insert(Symbol::from(symbol));
-                            return self.spin_absorb();
-                        }
-                        if ev.modifiers.is_none() && KeyBehavior::Absorb == shared.syl.key_press(ev)
-                        {
-                            return self.start_enter_syllable();
-                        }
-                        self.spin_bell()
-                    }
                     LanguageMode::Chinese => {
+                        if shared.options.easy_symbol_input && ev.modifiers.shift {
+                            // Priortize symbol input
+                            if let Some(expended) = shared.abbr.find_abbrev(ev.unicode) {
+                                expended
+                                    .chars()
+                                    .for_each(|ch| shared.com.insert(Symbol::from(ch)));
+                                return self.spin_absorb();
+                            }
+                        }
                         if ev.modifiers.is_none() && KeyBehavior::Absorb == shared.syl.key_press(ev)
                         {
                             return self.start_enter_syllable();
@@ -1464,6 +1470,9 @@ impl State for Selecting {
             Esc => {
                 shared.cancel_selecting();
                 shared.com.pop_cursor();
+                if shared.options.conversion_engine == ConversionEngineKind::SimpleEngine {
+                    shared.com.clear();
+                }
                 self.start_entering()
             }
             Del => {
@@ -1541,15 +1550,15 @@ mod tests {
         conversion::ChewingEngine,
         dictionary::{Layered, TrieBuf},
         editor::{
-            abbrev::AbbrevTable, estimate, keyboard::Modifiers, EditorKeyBehavior, SymbolSelector,
+            EditorKeyBehavior, SymbolSelector, abbrev::AbbrevTable, estimate, keyboard::Modifiers,
         },
         syl,
         zhuyin::Bopomofo,
     };
 
     use super::{
-        keyboard::{KeyCode, KeyboardLayout, Qwerty},
         BasicEditor, Editor,
+        keyboard::{KeyCode, KeyboardLayout, Qwerty},
     };
 
     #[test]
@@ -1804,5 +1813,22 @@ mod tests {
     }
 
     #[test]
-    fn editing_mode_input_symbol() {}
+    fn editing_mode_open_empty_symbol_table_then_bell() {
+        let keyboard = Qwerty;
+        let dict = Layered::new(
+            vec![Box::new(TrieBuf::new_in_memory())],
+            Box::new(TrieBuf::new_in_memory()),
+        );
+        let conversion_engine = Box::new(ChewingEngine::new());
+        let estimate = LaxUserFreqEstimate::new(0);
+        let abbrev = AbbrevTable::new();
+        let sym_sel = SymbolSelector::default();
+        let mut editor = Editor::new(conversion_engine, dict, estimate, abbrev, sym_sel);
+
+        let ev = keyboard.map(KeyCode::Grave);
+        let key_behavior = editor.process_keyevent(ev);
+
+        assert_eq!(EditorKeyBehavior::Bell, key_behavior);
+        assert_eq!(syl![], editor.syllable_buffer());
+    }
 }
