@@ -52,6 +52,7 @@ impl SyllableEditor for GinYieh {
             KeyIndex::K22 => Bopomofo::O,
             KeyIndex::K23 => Bopomofo::EI,
             KeyIndex::K24 => Bopomofo::EN,
+            KeyIndex::K25 => Bopomofo::U,
             KeyIndex::K27 => Bopomofo::TONE3,
             KeyIndex::K28 => Bopomofo::M,
             KeyIndex::K29 => Bopomofo::N,
@@ -60,7 +61,7 @@ impl SyllableEditor for GinYieh {
             KeyIndex::K32 => Bopomofo::SH,
             KeyIndex::K33 => Bopomofo::C,
             KeyIndex::K34 => Bopomofo::E,
-            KeyIndex::K35 => Bopomofo::OU,
+            KeyIndex::K35 => Bopomofo::AU,
             KeyIndex::K36 => Bopomofo::ANG,
             KeyIndex::K37 => Bopomofo::IU,
             KeyIndex::K38 => Bopomofo::TONE4,
